@@ -684,6 +684,9 @@ arv_gvsp_packet_type_get_type (void)
 			{ ARV_GVSP_PACKET_TYPE_OK,
 			  "ARV_GVSP_PACKET_TYPE_OK",
 			  "ok" },
+			{ ARV_GVSP_PACKET_TYPE_RESEND,
+			  "ARV_GVSP_PACKET_TYPE_RESEND",
+			  "resend" },
 			{ ARV_GVSP_PACKET_TYPE_ERROR,
 			  "ARV_GVSP_PACKET_TYPE_ERROR",
 			  "error" },
