@@ -550,10 +550,13 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size)
 
 	tokens = g_regex_split (arv_gv_device_get_url_regex (), filename, 0);
 
-	if (tokens[0] != NULL) {
-		if (g_strcmp0 (tokens[1], "File:") == 0)
-			g_file_get_contents (filename, &genicam, NULL, NULL);
-		else if (g_strcmp0 (tokens[1], "Local:") == 0 &&
+	if (tokens[0] != NULL && tokens[1] != NULL) {
+		if (g_ascii_strcasecmp (tokens[1], "file:") == 0) {
+			gsize len;
+			g_file_get_contents (tokens[2], &genicam, &len, NULL);
+			if (genicam)
+				*size = len;
+		} else if (g_ascii_strcasecmp (tokens[1], "local:") == 0 &&
 			 tokens[2] != NULL &&
 			 tokens[3] != NULL &&
 			 tokens[4] != NULL) {
@@ -615,6 +618,26 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size)
 					*size = 0;
 				}
 			}
+        } else if (g_ascii_strcasecmp (tokens[1], "http:") == 0) {
+			GFile *file;
+			GFileInputStream *stream;
+
+			file = g_file_new_for_uri (filename);
+			stream = g_file_read (file, NULL, NULL);
+			if(stream) {
+				GDataInputStream *data_stream;
+				gsize len;
+
+				data_stream = g_data_input_stream_new (G_INPUT_STREAM (stream));
+				genicam = g_data_input_stream_read_upto (data_stream, "", 0, &len, NULL, NULL);
+
+				if (genicam)
+					*size = len;
+
+				g_object_unref (data_stream);
+				g_object_unref (stream);
+			}
+			g_object_unref (file);
 		}
 	}
 
@@ -898,6 +921,12 @@ arv_gv_device_new (GInetAddress *interface_address, GInetAddress *device_address
 
 	arv_gv_device_load_genicam (gv_device);
 
+	if (!ARV_IS_GC (gv_device->priv->genicam)) {
+		arv_warning_device ("[GvDevice::new] Failed to load genicam data");
+		g_object_unref (gv_device);
+		return NULL;
+	}
+
 	arv_gv_device_take_control (gv_device);
 
 	heartbeat_data = g_new (ArvGvDeviceHeartbeatData, 1);
