@@ -390,7 +390,7 @@ arv_stream_class_init (ArvStreamClass *node_class)
 	arv_stream_signals[ARV_STREAM_SIGNAL_NEW_BUFFER] =
 		g_signal_new ("new-buffer",
 			      G_TYPE_FROM_CLASS (node_class),
-			      G_SIGNAL_RUN_LAST,
+			      0,
 			      G_STRUCT_OFFSET (ArvStreamClass, new_buffer),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0, G_TYPE_NONE);
